@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -135,7 +135,7 @@ exclude_link_by_id (gint k, GGobiData * sd, ggobid * gg)
   if (id < 0)              /*-- this would indicate a bug --*/
      /**/ return false;
 
-  for (l = gg->d; l; l = l->next) {
+   for (l = gg->d; l; l = l->next) {
     d = (GGobiData *) l->data;
     if (d == sd)
       continue;        /*-- skip the originating datad --*/
@@ -168,7 +168,7 @@ brush_link_by_var (gint jlinkby, vector_b * levelv,
                    cpaneld * cpanel, GGobiData * d, ggobid * gg)
 {
   gint m, i, level_value;
-
+ 
   /*
    * for this datad, loop once over all rows in plot 
    */
@@ -278,6 +278,7 @@ build_symbol_vectors_by_var (cpaneld * cpanel, GGobiData * d, ggobid * gg)
   GSList *l;
   GGobiData *dd;
   gboolean changed = false;
+  gint k, jlinkdd;
 
   if (d->linkvar_vt == NULL)
     return false;
@@ -317,9 +318,42 @@ build_symbol_vectors_by_var (cpaneld * cpanel, GGobiData * d, ggobid * gg)
     dd = l->data;
     if (dd != d) {
       /* If the linking variable exists in the other datad ... */
-      jlinkby = vartable_index_get_by_name(d->linkvar_vt->collab, dd);
-      if (jlinkby != -1) {
-        brush_link_by_var (jlinkby, &levelv, cpanel, dd, gg);
+      jlinkdd = vartable_index_get_by_name(d->linkvar_vt->collab, dd);
+      if (jlinkdd != -1) {
+
+        /* The level values in dd might not be the same as
+           the level values in the d */
+        vartabled *vtdd = vartable_element_get (jlinkdd, dd);
+        vector_b levelv_dd;
+
+        level_value_max = vtdd->nlevels;
+        for (i = 0; i < vtdd->nlevels; i++) {
+          level_value = vtdd->level_values[i];
+          if (level_value > level_value_max)
+            level_value_max = level_value;
+        }
+
+        vectorb_init_null (&levelv_dd);
+        vectorb_alloc (&levelv_dd, level_value_max + 1);
+        vectorb_zero (&levelv_dd);
+
+        for (i=0; i<d->linkvar_vt->nlevels; i++) {
+          if (levelv.els[ d->linkvar_vt->level_values[i] ] == true) {
+            for (k=0; k<vtdd->nlevels; k++) 
+            {
+              if (strcmp(vtdd->level_names[k], 
+                         d->linkvar_vt->level_names[i]) == 0) 
+              {
+                levelv_dd.els[ vtdd->level_values[k] ] = true;
+                break;
+              }
+            }
+          }
+        }
+
+        brush_link_by_var (jlinkdd, &levelv_dd, cpanel, dd, gg);
+        vectorb_free (&levelv_dd);
+
       }
     }
   }
@@ -427,6 +461,12 @@ linking_method_set_cb (GtkTreeSelection * treesel, ggobid * gg)
   GtkTreePath *path;
   gint row = -1;
 
+  /*
+  g_printerr ("display %d d->d %d d %d\n", (gint)gg->current_display,
+	      (gint)gg->current_display->d,
+	      (gint)d);
+  */
+
   if (gtk_tree_selection_get_selected (treesel, &model, &iter)) {
     path = gtk_tree_model_get_path (model, &iter);
     row = gtk_tree_path_get_indices (path)[0];
@@ -437,7 +477,7 @@ linking_method_set_cb (GtkTreeSelection * treesel, ggobid * gg)
    * actually correspond to the current data.  This looks more and
    * more like a kludge -- I do need to revisit this.  -- dfs
    */
-  if (gg->current_display->d == d) {
+  if (gg->current_display && gg->current_display->d == d) {
     displayd *display = gg->current_display;
     cpaneld *cpanel = &display->cpanel;
     cpanel->br.linkby_row = row;
