@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -285,9 +285,9 @@ motion_notify_cb (GtkWidget * w, GdkEventMotion * event, cpaneld * cpanel)
     fflush (stderr);
 #endif
 /*XX is this the correct source object? */
-    if (changed)
-      g_signal_emit (G_OBJECT (gg), GGobiSignals[BRUSH_MOTION_SIGNAL], 0,
-                     sp, event, sp->displayptr->d);
+    /*if (changed)*/ /* MFL: emit signal whenever brush moves */
+    g_signal_emit (G_OBJECT (gg), GGobiSignals[BRUSH_MOTION_SIGNAL], 0,
+                   sp, event, sp->displayptr->d);
   }
   return true;
 }
