@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -272,6 +272,8 @@ gint       edgesets_count (ggobid *gg);
 void       eigenvals_get (gfloat *, GGobiData *);
 gboolean   exclude_link_by_id (gint k, GGobiData *source_d, ggobid *gg);
 gint       fcompare (const void *x1, const void *x2);
+gint       icompare (const void *x1, const void *x2);
+gint       scompare (const void *x1, const void *x2);
 void       filename_get_r (ggobid *);
 void       filename_get_w (GtkWidget *, ggobid *);
 GSList*    fileset_read (const gchar *, const gchar *modeName, GGobiPluginInfo *, ggobid *);
@@ -445,6 +447,7 @@ void       splot_add_identify_edge_cues (splotd *sp, GdkDrawable *drawable, gint
 void       splot_add_point_label (gboolean, gint, gboolean, splotd *, GdkDrawable *, ggobid *);
 void       splot_connect_expose_handler (gint, splotd *);
 void       splot_cursor_set (gint jcursor, splotd *sp);
+void       splot_cursor_unset (splotd *sp);
 void       splot_dimension_set(splotd* sp, gint width, gint height);
 void       splot_draw_tour_axes(splotd *sp, GdkDrawable *, ggobid *);
 void       splot_edges_draw (splotd *sp, gboolean hiddens_p, GdkDrawable *drawable, ggobid *gg);
