@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -73,99 +73,101 @@ ggobi_ggobi_get_type (void)
 void
 ggobi_ggobi_class_init (GGobiGGobiClass * klass)
 {
-  if (g_signal_lookup ("datad_added", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[DATAD_ADDED_SIGNAL] =
-      g_signal_new ("datad_added",
-                    G_TYPE_FROM_CLASS (klass),
-                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    g_cclosure_marshal_VOID__OBJECT,
-                    G_TYPE_NONE, 1, GGOBI_TYPE_DATA);
-  }
+  GGobiSignals[DATAD_ADDED_SIGNAL] =
+    g_signal_new ("datad_added",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  g_cclosure_marshal_VOID__OBJECT,
+                  G_TYPE_NONE, 1, GGOBI_TYPE_DATA);
 
-  if (g_signal_lookup ("brush_motion", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[BRUSH_MOTION_SIGNAL] = g_signal_new ("brush_motion", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, ggobi_marshal_VOID__OBJECT_POINTER_OBJECT, G_TYPE_NONE, 3, GGOBI_TYPE_SPLOT, G_TYPE_POINTER, /* GdkEventMotion pointer */
-                                                      GGOBI_TYPE_DATA);
-  }
+  GGobiSignals[BRUSH_MOTION_SIGNAL] =
+    g_signal_new ("brush_motion", G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  ggobi_marshal_VOID__OBJECT_POINTER_OBJECT, G_TYPE_NONE, 3,
+                  GGOBI_TYPE_SPLOT, G_TYPE_POINTER, /* GdkEventMotion pointer */
+                  GGOBI_TYPE_DATA);
 
-  if (g_signal_lookup ("move_point", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[POINT_MOVE_SIGNAL] =
-      g_signal_new ("move_point",
-                    G_TYPE_FROM_CLASS (klass),
-                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    ggobi_marshal_VOID__OBJECT_INT_OBJECT,
-                    G_TYPE_NONE, 3,
-                    GGOBI_TYPE_SPLOT, G_TYPE_INT, GGOBI_TYPE_DATA);
-  }
-
-  if (g_signal_lookup ("identify_point", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[IDENTIFY_POINT_SIGNAL] =
-      g_signal_new ("identify_point",
-                    G_TYPE_FROM_CLASS (klass),
-                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    ggobi_marshal_VOID__OBJECT_INT_OBJECT,
-                    G_TYPE_NONE, 3,
-                    GGOBI_TYPE_SPLOT, G_TYPE_INT, GGOBI_TYPE_DATA);
-  }
+  GGobiSignals[POINT_MOVE_SIGNAL] =
+    g_signal_new ("move_point",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  ggobi_marshal_VOID__OBJECT_INT_OBJECT,
+                  G_TYPE_NONE, 3,
+                  GGOBI_TYPE_SPLOT, G_TYPE_INT, GGOBI_TYPE_DATA);
+ 
+  GGobiSignals[IDENTIFY_POINT_SIGNAL] =
+    g_signal_new ("identify_point",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  ggobi_marshal_VOID__OBJECT_INT_OBJECT,
+                  G_TYPE_NONE, 3,
+                  GGOBI_TYPE_SPLOT, G_TYPE_INT, GGOBI_TYPE_DATA);
 
   /* This should be for a ggobi datad rather than a widget. Make that a
      GObject and give it a type. */
-  if (g_signal_lookup ("select_variable", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[VARIABLE_SELECTION_SIGNAL] =
-      g_signal_new ("select_variable",
-                    G_TYPE_FROM_CLASS (klass),
+  GGobiSignals[VARIABLE_SELECTION_SIGNAL] =
+    g_signal_new ("select_variable",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  ggobi_marshal_VOID__OBJECT_INT_OBJECT,
+                  G_TYPE_NONE, 3,
+                  GGOBI_TYPE_DATA, G_TYPE_INT, GGOBI_TYPE_SPLOT);
+
+  GGobiSignals[SPLOT_NEW_SIGNAL] =
+    g_signal_new ("splot_new",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  g_cclosure_marshal_VOID__OBJECT,
+                  G_TYPE_NONE, 1, GGOBI_TYPE_SPLOT);
+  
+    GGobiSignals[VARIABLE_ADDED_SIGNAL] =
+      g_signal_new ("variable_added", G_TYPE_FROM_CLASS (klass),
                     G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    ggobi_marshal_VOID__OBJECT_INT_OBJECT,
-                    G_TYPE_NONE, 3,
-                    GGOBI_TYPE_DATA, G_TYPE_INT, GGOBI_TYPE_SPLOT);
-  }
+                    ggobi_marshal_VOID__POINTER_INT_OBJECT, G_TYPE_NONE, 3,
+                    G_TYPE_POINTER,  /*vartabled XX */
+                    G_TYPE_INT, /*index variable */
+                    GGOBI_TYPE_DATA);
 
-  if (g_signal_lookup ("splot_new", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[SPLOT_NEW_SIGNAL] =
-      g_signal_new ("splot_new",
-                    G_TYPE_FROM_CLASS (klass),
-                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    g_cclosure_marshal_VOID__OBJECT,
-                    G_TYPE_NONE, 1, GGOBI_TYPE_SPLOT);
-  }
-
-  if (g_signal_lookup ("variable_added", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[VARIABLE_ADDED_SIGNAL] = g_signal_new ("variable_added", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, ggobi_marshal_VOID__POINTER_INT_OBJECT, G_TYPE_NONE, 3, G_TYPE_POINTER,  /*vartabled XX */
-                                                        G_TYPE_INT, /*index variable */
-                                                        GGOBI_TYPE_DATA);
-  }
-
-  if (g_signal_lookup ("variable_list_changed", GGOBI_TYPE_GGOBI) == 0) {
     GGobiSignals[VARIABLE_LIST_CHANGED_SIGNAL] =
       g_signal_new ("variable_list_changed",
                     G_TYPE_FROM_CLASS (klass),
                     G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
                     g_cclosure_marshal_VOID__OBJECT,
                     G_TYPE_NONE, 1, GGOBI_TYPE_DATA);
-  }
-
-  if (g_signal_lookup ("sticky_point_added", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[STICKY_POINT_ADDED_SIGNAL] = g_signal_new ("sticky_point_added", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, ggobi_marshal_VOID__INT_INT_OBJECT, G_TYPE_NONE, 3, G_TYPE_INT, G_TYPE_INT, GGOBI_TYPE_DATA);  /* record index and datad pointer */
-  }
-
-  if (g_signal_lookup ("sticky_point_removed", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[STICKY_POINT_REMOVED_SIGNAL] = g_signal_new ("sticky_point_removed", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, ggobi_marshal_VOID__INT_INT_OBJECT, G_TYPE_NONE, 3, G_TYPE_INT, G_TYPE_INT, GGOBI_TYPE_DATA);  /* record index and datad pointer */
-  }
-
-  if (g_signal_lookup ("clusters_changed", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[CLUSTERS_CHANGED_SIGNAL] = g_signal_new ("clusters_changed", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GGOBI_TYPE_DATA); /* datad pointer */
-  }
-
-
-  if (g_signal_lookup ("display_new", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[DISPLAY_NEW_SIGNAL] = g_signal_new ("display_new", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GGOBI_TYPE_DISPLAY);  /* displayd pointer */
-  }
-
+    
+    GGobiSignals[STICKY_POINT_ADDED_SIGNAL] =
+      g_signal_new ("sticky_point_added", G_TYPE_FROM_CLASS (klass),
+                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                    ggobi_marshal_VOID__INT_INT_OBJECT, G_TYPE_NONE, 3,
+                    G_TYPE_INT, G_TYPE_INT,
+                    GGOBI_TYPE_DATA);  /* record index and datad pointer */
+    
+    GGobiSignals[STICKY_POINT_REMOVED_SIGNAL] =
+      g_signal_new ("sticky_point_removed", G_TYPE_FROM_CLASS (klass),
+                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                    ggobi_marshal_VOID__INT_INT_OBJECT, G_TYPE_NONE, 3,
+                    G_TYPE_INT, G_TYPE_INT,
+                    GGOBI_TYPE_DATA);  /* record index and datad pointer */
 
+    GGobiSignals[CLUSTERS_CHANGED_SIGNAL] =
+      g_signal_new ("clusters_changed", G_TYPE_FROM_CLASS (klass),
+                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                    g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
+                    GGOBI_TYPE_DATA); /* datad pointer */
+    
+    GGobiSignals[DISPLAY_NEW_SIGNAL] =
+      g_signal_new ("display_new", G_TYPE_FROM_CLASS (klass),
+                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                    g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
+                    GGOBI_TYPE_DISPLAY);  /* displayd pointer */
+    
   /* This signal is to be emitted by display_set_current, and picked
      up by the console. */
-  if (g_signal_lookup ("display_selected", GGOBI_TYPE_GGOBI) == 0) {
-    GGobiSignals[DISPLAY_SELECTED_SIGNAL] = g_signal_new ("display_selected", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GGOBI_TYPE_DISPLAY);  /* displayd pointer */
-  }
+    GGobiSignals[DISPLAY_SELECTED_SIGNAL] =
+      g_signal_new ("display_selected", G_TYPE_FROM_CLASS (klass),
+                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                    g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1,
+                    GGOBI_TYPE_DISPLAY);  /* displayd pointer */
 
   /*int i;
      for (i = 0; i < MAX_GGOBI_SIGNALS; i++) {
@@ -199,15 +201,13 @@ ggobi_display_class_init (GGobiDisplayClass * klass)
   G_OBJECT_CLASS (klass)->destroy = testDisplayDestroy;
 #endif
 
-  if (g_signal_lookup ("tour_step", GGOBI_TYPE_DISPLAY) == 0) {
-    klass->signals[TOUR_STEP_SIGNAL] =
-      g_signal_new ("tour_step",
-                    G_TYPE_FROM_CLASS (klass),
-                    G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
-                    ggobi_marshal_VOID__POINTER_INT_OBJECT,
-                    G_TYPE_NONE, 3,
-                    G_TYPE_POINTER, G_TYPE_INT, GGOBI_TYPE_GGOBI);
-  }
+  klass->signals[TOUR_STEP_SIGNAL] =
+    g_signal_new ("tour_step",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0, NULL, NULL,
+                  ggobi_marshal_VOID__POINTER_INT_OBJECT,
+                  G_TYPE_NONE, 3,
+                  G_TYPE_POINTER, G_TYPE_INT, GGOBI_TYPE_GGOBI);
 }
 
 static void
