@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -412,9 +412,9 @@ viewmode_set (ProjectionMode pmode, InteractionMode imode, ggobid * gg)
     gg->current_control_panel = panel;
 
     /*-- avoid increasing the object's ref_count infinitely  --*/
-
-    if (G_OBJECT (panel)->ref_count > 1)
-      gtk_widget_unref (panel);
+    /* wow, super-dangerous - do we really need this? - mfl */
+    /*if (G_OBJECT (panel)->ref_count > 1)
+      gtk_widget_unref (panel);*/
   }
 
   if (pmode != NULL_PMODE && gg->pmode != gg->pmode_prev) {
@@ -487,15 +487,15 @@ imode_activate (splotd * sp, ProjectionMode pmode, InteractionMode imode,
         break;
       case TOUR2D3:
         if (cpanel->t2d3.manip_mode != MANIP_OFF)
-          splot_cursor_set ((gint) NULL, sp);
+          splot_cursor_unset (sp);
         break;
       case TOUR2D:
         if (cpanel->t2d.manip_mode != MANIP_OFF)
-          splot_cursor_set ((gint) NULL, sp);
+          splot_cursor_unset (sp);
         break;
       case COTOUR:
         if (cpanel->tcorr.manip_mode != MANIP_OFF)
-          splot_cursor_set ((gint) NULL, sp);
+          splot_cursor_unset (sp);
         break;
       case TOUR1D:
       case NULL_PMODE:
@@ -513,7 +513,7 @@ imode_activate (splotd * sp, ProjectionMode pmode, InteractionMode imode,
       redraw_style = identify_activate (state, display, gg);
       break;
     case SCALE:
-      splot_cursor_set ((gint) NULL, sp);
+      splot_cursor_unset (sp);
         /*-- for insurance, because sometimes scaling doesn't quit --*/
       disconnect_motion_signal (sp);
         /*-- --*/
