@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -176,19 +176,6 @@ pipeline_arrays_check_dimensions (GGobiData * d)
 /*                       pipeline                                          */
 /*-------------------------------------------------------------------------*/
 
-gint
-icompare (gint * x1, gint * x2)
-{
-  gint val = 0;
-
-  if (*x1 < *x2)
-    val = -1;
-  else if (*x1 > *x2)
-    val = 1;
-
-  return (val);
-}
-
 gfloat
 median_largest_dist (gfloat ** vals, gint * cols, gint ncols,
                      gfloat * min, gfloat * max, GGobiData * d, ggobid * gg)
