@@ -1,10 +1,10 @@
-/* read_xml.c */
+ /* read_xml.c */
 /*
  * ggobi
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -82,7 +82,7 @@
 #include "GGobiAPI.h"
 
 
-void setColorScheme (const xmlChar ** attrs, XMLParserData * data);
+void setGGobiColorScheme (const xmlChar ** attrs, XMLParserData * data);
 
 void startXMLElement (void *user_data, const xmlChar * name,
                       const xmlChar ** attrs);
@@ -355,7 +355,7 @@ startXMLElement (void *user_data, const xmlChar * name,
 
   switch (type) {
   case COLORSCHEME:
-    setColorScheme (attrs, data);
+    setGGobiColorScheme (attrs, data);
     break;
   case VARIABLES:
     allocVariables (attrs, data);
@@ -430,7 +430,7 @@ startXMLElement (void *user_data, const xmlChar * name,
 }
 
 void
-setColorScheme (const xmlChar ** attrs, XMLParserData * data)
+setGGobiColorScheme (const xmlChar ** attrs, XMLParserData * data)
 {
   const gchar *tmp;
 
@@ -855,7 +855,12 @@ Characters (void *user_data, const xmlChar * ch, gint len)
   const xmlChar *c;
   XMLParserData *data = (XMLParserData *) user_data;
 
-  c = (const xmlChar *) skipWhiteSpace (ch, &dlen);
+  if(data->recordStringLength == 0) {
+    c = (const xmlChar *) skipWhiteSpace (ch, &dlen);
+  } else {
+    c = ch;
+  }
+  
   if (dlen < 1 || c[0] == '\n')
     return;
 
@@ -2023,7 +2028,8 @@ isXMLFile (const gchar * fileName, ggobid * gg, GGobiPluginInfo * info)
       continue;
     if (c == '<') {
       gchar buf[10];
-      fgets (buf, 5, f);
+      if (fgets (buf, 5, f) == NULL)
+        return (false);
       fclose (f);
       if (strcmp (buf, "?xml") == 0) {
         return (true);
