@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -165,10 +165,10 @@ plottedVarsGet (displayd * display, gint * vars, GGobiData * d, ggobid * gg)
 }
 
 displayd *
-createWithVars (gboolean missing_p, gint nvars, gint * vars, GGobiData * d,
-                ggobid * gg)
+createWithVars (gboolean use_window, gboolean missing_p, gint nvars, 
+                gint * vars, GGobiData * d, ggobid * gg)
 {
-  return (GGOBI (newScatmat) (vars, vars, nvars, nvars, d, gg));
+  return (GGOBI (newScatmat) (vars, vars, nvars, nvars, use_window, d, gg));
 }
 
 #ifdef STORE_SESSION_ENABLED
