@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -63,17 +63,17 @@ splot_configure_cb (GtkWidget *w, GdkEventConfigure *event, splotd *sp)
     gdk_pixmap_unref (sp->pixmap0);
   if (sp->pixmap1 != NULL)
     gdk_pixmap_unref (sp->pixmap1);
-
+/*
   sp->pixmap0 = gdk_pixmap_new (w->window,
     w->allocation.width, w->allocation.height, -1);
   sp->pixmap1 = gdk_pixmap_new (w->window,
     w->allocation.width, w->allocation.height, -1);
+*/
 
-/*
   renderer = ggobi_renderer_factory_create(factory, w->window);
   sp->pixmap0 = GDK_DRAWABLE(renderer);
   renderer = ggobi_renderer_factory_create(factory, w->window);
-  sp->pixmap1 = GDK_DRAWABLE(renderer);*/
+  sp->pixmap1 = GDK_DRAWABLE(renderer);
   g_object_unref(G_OBJECT(factory));
   
   if (cpanel->imode == BRUSH) {
@@ -108,6 +108,10 @@ splot_configure_cb (GtkWidget *w, GdkEventConfigure *event, splotd *sp)
   sp->redraw_style = FULL;
   gtk_widget_queue_draw (sp->da);
 
+  /* if no window, then the ruler ranges have not yet been set: set them now */
+  if (GGOBI_IS_WINDOW_DISPLAY(display) && !GGOBI_WINDOW_DISPLAY(display)->useWindow)
+    ruler_ranges_set(true, display, sp, gg);
+  
   return false;
 }
 
@@ -917,19 +921,28 @@ disconnect_scroll_signal (splotd *sp) {
  * Return to the default cursor
 */
 void
-splot_cursor_set (gint jcursor, splotd *sp)
+splot_cursor_unset (splotd *sp)
 {
   GdkWindow *window = sp->da->window;
 
-  if (jcursor == (gint) NULL) {
-    if (sp->cursor != NULL)
-      gdk_cursor_destroy (sp->cursor);
-    sp->jcursor = (gint) NULL;
-    sp->cursor = (gint) NULL;
-    gdk_window_set_cursor (window, NULL);
-  } else {
-    sp->jcursor = (gint) jcursor;
-    sp->cursor = gdk_cursor_new (sp->jcursor);
-    gdk_window_set_cursor (window, sp->cursor);
-  }
+  if (!GTK_WIDGET_REALIZED(sp->da))
+    return;
+
+  sp->jcursor = 0;
+  if (sp->cursor != NULL)
+    gdk_cursor_destroy (sp->cursor);
+  sp->cursor = NULL;
+  gdk_window_set_cursor (window, NULL);
+}
+
+void
+splot_cursor_set (GdkCursorType jcursor, splotd *sp)
+{
+  GdkWindow *window = sp->da->window;
+
+  if (!GTK_WIDGET_REALIZED(sp->da))
+    return;
+
+  sp->cursor = gdk_cursor_new (sp->jcursor);
+  gdk_window_set_cursor (window, sp->cursor);
 }
