@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -71,7 +71,7 @@ set_adjustment (GtkWidget *w, GtkAdjustment *adj_new)
   if (w) {
     btn = GTK_SPIN_BUTTON (w);
     adj_current = gtk_spin_button_get_adjustment (btn);
-    if ((gint)adj_current != (gint)adj_new) {
+    if (adj_current != adj_new) {
       g_object_ref (G_OBJECT(adj_current));
       gtk_spin_button_set_adjustment (btn, adj_new);
     }
@@ -243,7 +243,7 @@ subset_tree_view_datad_added_cb (ggobid *gg, GGobiData *d, GtkWidget *tree_view)
   subset_init (d, gg);
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(tree_view));
   gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-  gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, d->name);
+  gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, d->name, -1);
 
   gtk_widget_show_all (swin);
 }
@@ -295,7 +295,7 @@ subset_window_open (ggobid *gg) {
       model = gtk_list_store_new(1, G_TYPE_STRING);
       tree_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
       populate_tree_view(tree_view, tree_view_titles, G_N_ELEMENTS(tree_view_titles), 
-        true, GTK_SELECTION_SINGLE, G_CALLBACK(subset_datad_set_cb), gg);
+        true, GTK_SELECTION_BROWSE, G_CALLBACK(subset_datad_set_cb), gg);
       
       g_object_set_data(G_OBJECT (tree_view), "datad_swin", swin);
       g_signal_connect (G_OBJECT (gg), "datad_added",
