@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -19,7 +19,6 @@
 #include <strings.h>
 #endif
 
-#define __USE_ISOC99
 #include <math.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -820,6 +819,8 @@ tour1d_idle_func (displayd *dsp)
 
 void tour1d_func (gboolean state, displayd *dsp, ggobid *gg)
 {
+  splotd *sp = (splotd *) g_list_nth_data (dsp->splots, 0);
+
   if (state) {
     if (dsp->t1d.idled == 0) {
       dsp->t1d.idled = g_idle_add_full (G_PRIORITY_LOW,
@@ -833,6 +834,8 @@ void tour1d_func (gboolean state, displayd *dsp, ggobid *gg)
     }
     gg->tour1d.idled = 0;
   }
+
+  splot_connect_expose_handler (dsp->t1d.idled, sp);
 }
 
 void tour1d_reinit(ggobid *gg)
