@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -19,8 +19,6 @@
 #include <strings.h>
 #endif
 
-#define __USE_ISOC99
-
 #include <math.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -813,6 +811,13 @@ tour2d_idle_func (displayd *dsp)
 
 void tour2d_func (gboolean state, displayd *dsp, ggobid *gg)
 {
+  /* 
+   * Since the tour variables are stored at the display level,
+   * assume for the time being that a display with a tour must
+   * be running in the first and only splot.
+   */
+  splotd *sp = (splotd *) g_list_nth_data (dsp->splots, 0);
+
   if (state) {
     if (dsp->t2d.idled == 0) {
       dsp->t2d.idled = g_idle_add_full (G_PRIORITY_LOW,
@@ -827,6 +832,8 @@ void tour2d_func (gboolean state, displayd *dsp, ggobid *gg)
     }
     gg->tour2d.idled = 0;
   }
+
+  splot_connect_expose_handler (dsp->t2d.idled, sp);
 }
 
 void tour2d_reinit(ggobid *gg)
