@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -146,7 +146,7 @@ static void manip_cb (GtkWidget *w, ggobid *gg)
   cpanel->t2d.manip_mode = gtk_combo_box_get_active(GTK_COMBO_BOX(w));
 
   if (cpanel->t2d.manip_mode == MANIP_OFF)
-    splot_cursor_set ((gint) NULL, sp);
+    splot_cursor_unset (sp);
   else
     splot_cursor_set (GDK_HAND2, sp);
 }
@@ -684,7 +684,7 @@ tour2d_event_handlers_toggle (splotd *sp, gboolean state) {
   displayd *display = (displayd *) sp->displayptr;
 
   if (state == on) {
-    if(GGOBI_IS_WINDOW_DISPLAY(display))
+    if(GGOBI_IS_WINDOW_DISPLAY(display) && GGOBI_WINDOW_DISPLAY(display)->useWindow)
       sp->key_press_id = g_signal_connect (G_OBJECT (GGOBI_WINDOW_DISPLAY(display)->window),
         "key_press_event",
         G_CALLBACK(key_press_cb),
