@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -23,7 +23,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_ISOC99
 #include <math.h>
 #include <gtk/gtk.h>
 #include "vars.h"
@@ -248,6 +247,7 @@ transform1_apply (gint j, GGobiData *d, ggobid *gg)
   gfloat ref, ftmp;
   gboolean tform_ok = true;
   gdouble dtmp;
+  // gcc complains about uninitialized values here, but it's ok.
   lims slim, slim_tform;  /*-- specified limits --*/
   GtkWidget *stage1_cbox;
   gint tform1;
@@ -298,6 +298,7 @@ transform1_apply (gint j, GGobiData *d, ggobid *gg)
           }
         }
         /*-- apply the same domain test to the specified limits --*/
+        // gcc complains about uninitialized values here, but it's ok.
         if (tform_ok && vt->lim_specified_p) {
           if (((*domain_adj)(slim_tform.min, incr) <= 0) ||
               ((*domain_adj)(slim_tform.max, incr) <= 0))
