@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -160,8 +160,8 @@ varsel (GtkWidget * w, cpaneld * cpanel, splotd * sp, gint jvar,
   displayd *display = (displayd *) sp->displayptr;
   gboolean redraw = false;
 
-  if (display == NULL || !GGOBI_IS_WINDOW_DISPLAY (display) ||
-      !GTK_IS_WIDGET (GGOBI_WINDOW_DISPLAY (display)->window)) {
+  if (display == NULL /*|| !GGOBI_IS_WINDOW_DISPLAY (display) ||
+      !GTK_IS_WIDGET (GGOBI_WINDOW_DISPLAY (display)->window)*/) {
     g_printerr ("Bug?  I see no active display\n");
     return;
   }
